X-Git-Url: http://wagnertech.de/gitweb/gitweb.cgi/timetracker.git/blobdiff_plain/10a6f13349f497f4e2e5c7c4812fcb48db65310e..e0929a3b47f8a28dcbafae87c8d7de82b5e858dd:/WEB-INF/resources/zh-tw.lang.php
diff --git a/WEB-INF/resources/zh-tw.lang.php b/WEB-INF/resources/zh-tw.lang.php
index 4441ce2e..1bed9284 100644
--- a/WEB-INF/resources/zh-tw.lang.php
+++ b/WEB-INF/resources/zh-tw.lang.php
@@ -252,9 +252,9 @@ $i18n_key_words = array(
'title.login' => 'ç»é',
'title.groups' => 'åé', // TODO: change "teams" to "groups".
// TODO: translate the following.
-// 'title.create_team' => 'Creating Team',
-// 'title.edit_team' => 'Editing Team',
-'title.delete_team' => 'åªé¤åé',
+// 'title.create_group' => 'Creating Group',
+// 'title.edit_group' => 'Editing Group',
+'title.delete_group' => 'åªé¤åé', // TODO: change "team" to "group".
'title.reset_password' => 'éè¨å¯ç¢¼',
// TODO: translate the following.
// 'title.change_password' => 'Changing Password',
@@ -309,8 +309,8 @@ $i18n_key_words = array(
// 'title.edit_notification' => 'Editing Notification',
// 'title.delete_notification' => 'Deleting Notification',
// 'title.monthly_quotas' => 'Monthly Quotas',
-// 'title.export' => 'Exporting Team Data',
-// 'title.import' => 'Importing Team Data',
+// 'title.export' => 'Exporting Group Data',
+// 'title.import' => 'Importing Group Data',
'title.options' => 'é¸é
',
// TODO: translate the following.
// 'title.profile' => 'Profile',
@@ -324,7 +324,7 @@ $i18n_key_words = array(
// 'title.cf_edit_dropdown_option' => 'Editing Option',
// 'title.cf_delete_dropdown_option' => 'Deleting Option',
// NOTE TO TRANSLATORS: Locking is a feature to lock records from modifications (ex: weekly on Mondays we lock all previous weeks).
// It is also a name for the Locking plugin on the Team profile page.
// 'title.locking' => 'Locking',
// 'title.week_view' => 'Week View',
// 'title.swap_roles' => 'Swapping Roles',
@@ -474,20 +474,21 @@ $i18n_key_words = array(
// 'form.client.client_to_delete' => 'Client to delete',
// 'form.client.client_entries' => 'Client entries',
-// Exporting Team Data form. See example at https://timetracker.anuko.com/export.php
+// Exporting Group Data form. See example at https://timetracker.anuko.com/export.php
+// TODO: replace "team" with "group" in the string below.
'form.export.hint' => 'æ¨å¯ä»¥å°ææåéè³æå¯åºå°xmlæªã妿æ¨è¦å°è³æè½ç§»å°æ¨èªå·±ç伺æå¨ï¼éé
æä½å¾æç¨ã',
'form.export.compression' => 'å£ç¸®',
'form.export.compression_none' => 'ä¸å缩',
'form.export.compression_bzip' => 'bzipæ ¼å¼',
-// Importing Team Data form. See example at https://timetracker.anuko.com/imort.php (login as admin first).
+// Importing Group Data form. See example at https://timetracker.anuko.com/imort.php (login as admin first).
'form.import.hint' => 'å¾xmlæªå°å
¥åéè³æã',
'form.import.file' => '鏿æª',
'form.import.success' => 'æå宿å°å
¥ã',
-// Teams form. See example at https://timetracker.anuko.com/admin_teams.php (login as admin first).
-// TODO: translate the following.
-'form.teams.hint' => 'ééåµå»ºæ°çåéç¶ç帳èä¾åµå»ºæ°åéã
æ¨ä¹å¯ä»¥å¾å
¶å®çAnukoæé追蹤å¨ä¼ºæå¨çxmlæªå°å
¥åéè³æ(ç»éè³è¨ä¸è½ç¼çè¡çª)ã',
+// Groups form. See example at https://timetracker.anuko.com/admin_teams.php (login as admin first).
+// TODO: replace "team" with "group" in the string below.
+'form.groups.hint' => 'ééåµå»ºæ°çåéç¶ç帳èä¾åµå»ºæ°åéã
æ¨ä¹å¯ä»¥å¾å
¶å®çAnukoæé追蹤å¨ä¼ºæå¨çxmlæªå°å
¥åéè³æ(ç»éè³è¨ä¸è½ç¼çè¡çª)ã',
@@ -324,7 +324,7 @@ $i18n_key_words = array(
// 'title.cf_delete_dropdown_option' => 'Deleting Option',
// NOTE TO TRANSLATORS: Locking is a feature to lock records from modifications (ex: weekly on Mondays we lock all previous weeks).
-// It is also a name for the Locking plugin on the Team profile page.
+// It is also a name for the Locking plugin on the group settings page.
// 'title.locking' => 'Locking',
// 'title.week_view' => 'Week View',
// Profile form. See example at https://timetracker.anuko.com/profile_edit.php.
// TODO: translate the following.